from core.fields.base import LongCharField
from core.fields.color import ColorField
from core.fields.numbers import CostField
from core.models.local import Currency
from core.models.brands import Brand

from django.db.models import Model, PositiveIntegerField, ForeignKey, CASCADE, CharField, TextField, ManyToManyField, BooleanField

from importlib import import_module

import logging

logger = logging.getLogger(__name__)

class ProductGroup(Model):
    name = LongCharField()
    color = ColorField()

class Product(Model):
    name = LongCharField()
    description = TextField(null=True, blank=True)
    product_type = LongCharField(null=True, blank=True)
    product_groups = ManyToManyField(ProductGroup)
    brand = ForeignKey(Brand, on_delete=CASCADE)

    @property
    def handler(self):
        if self.product_type:
            try:
                product_type = import_module(self.product_type)
                return product_type.ProductRouter(self)
            except Exception as e:
                logger.error(f"Could not load product type {self.product_type} for product {self.id}: {e}")
        return None

class ProductPlan(Model):
    product = ForeignKey(Product, on_delete=CASCADE)
    currency = ForeignKey(Currency, on_delete=CASCADE)

class ProductPlanItem(Model):
    from core.mixins.billable import CycleChoices

    plan = ForeignKey(ProductPlan, on_delete=CASCADE)
    cycle = PositiveIntegerField(choices=CycleChoices.choices)
    count = PositiveIntegerField()
    cost = CostField()
    taxable = BooleanField()



    