from django.db.models import Model, ForeignKey, CASCADE, PositiveIntegerField, TextField, BooleanField, DateField, SET_NULL, PROTECT

from core.fields.base import LongCharField
from core.fields.numbers import CostField
from core.models.profiles import ClientProfile
from core.models.local import Currency
from core.models.brands import Brand
from core.models.services import Service

class Quote(Model):
    client = ForeignKey(ClientProfile, on_delete=PROTECT)
    brand = ForeignKey(Brand, on_delete=PROTECT)
    number = LongCharField()
    created = DateField()
    expiry = DateField()
    currency = ForeignKey(Currency, on_delete=PROTECT)

    @property
    def display_number(self):
        return self.number or self.id

class QuoteItem(Model):
    invoice = ForeignKey(Quote, on_delete=CASCADE)
    sort = PositiveIntegerField()
    name = LongCharField()
    description = TextField(blank=True, null=True)
    price = CostField()
    discount = CostField()
    taxable = BooleanField()
    service = ForeignKey(Service, on_delete=SET_NULL, null=True)
