import importlib

from django.conf import settings

from dbsettings.functions import getValue

import logging

logger = logging.getLogger(__name__)

providers = []

modules_available = []

for module in settings.EXPEPHALON_MODULES:
    try:
        mos = importlib.import_module(f"{module}.sms")
        for provider in mos.SMSPROVIDERS:
            providers.append(provider)
        if mos.CREATE:
            modules_available.append(mos.CREATE)
    except (AttributeError, ModuleNotFoundError, RuntimeError):
        continue
    except Exception as e:
        logger.error("Error importing SMS module {module}: {e}")

def get_sms_provider_by_name(name, active=False):
    for provider in providers:
        try:
            if provider.get_name == name:
                if provider.is_active or not active:
                    return provider
        except Exception as e:
            logger.error("Error checking SMS module {provider.get_name}: {e}")

def get_default_sms_provider_name(default=False):
    return getValue("core.sms.default", default)

def get_default_sms_provider(active=True):
    provider = get_sms_provider_by_name(get_default_sms_provider_name(), active)
    if provider:
        return provider

    for provider in providers:
        try:
            if provider.is_active or not active:
                return provider
        except Exception as e:
            logger.error("Error checking SMS module {provider.get_name}: {e}")

    raise RuntimeError("No SMS provider is currently active")
